@@ -1,11 +1,11 @@
-#!/usr/bin/python2.6
+#!/usr/bin/python
 # @package      hubzero-mailgateway
 # @file         filecopy.py
 # @author       David Benham <dbenham@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -27,9 +27,13 @@
 #
 
 import sys
-sys.path.insert(1,"/usr/lib/python2.6/dist-packages")
-
 import os
+
+dist_packages = "/usr/lib/python%d.%d/dist-packages" % (sys.version_info[0], sys.version_info[1])
+
+if os.path.isdir(dist_packages):
+    sys.path.insert(1,dist_packages)
+
 import pwd
 import grp
 import traceback
