@@ -1,11 +1,11 @@
-#!/usr/bin/python2.6
+#!/usr/bin/python
 # @package      hubzero-mailgateway
 # @file         processticketcomment.py
 # @author       David Benham <dbenham@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -27,7 +27,12 @@
 #
 
 import sys
-sys.path.insert(1,"/usr/lib/python2.6/dist-packages")
+import os
+
+dist_packages = "/usr/lib/python%d.%d/dist-packages" % (sys.version_info[0], sys.version_info[1])
+
+if os.path.isdir(dist_packages):
+    sys.path.insert(1,dist_packages)
 
 import base64
 import cgi
@@ -38,7 +43,6 @@ import errno
 import fcntl
 import mailproc
 import MySQLdb
-import os
 import re
 import smtplib
 import string
@@ -220,7 +224,7 @@ try:
 			sql = "select t.id, t.summary, t.created, ju_creator.email, ju_creator.id, ju_owner.email, ju_owner.id, t.status, t.resolved "
 			sql += "from jos_support_tickets t "
 			sql += "left join jos_users ju_creator on (ju_creator.username = t.login) "
-			sql += "left join jos_users ju_owner on (ju_owner.username = t.owner) "
+			sql += "left join jos_users ju_owner on (ju_owner.id = t.owner) "
 			sql += "where t.id = " + str(ticketID)
 
 			cursor.execute(sql)
@@ -354,7 +358,7 @@ try:
 			cursor = db.cursor ()
 			sql  = "INSERT INTO jos_support_comments (ticket, comment, created, created_by, changelog, access) "
 			sql += "VALUES( %s, %s, %s, %s, %s, %s )"
-			data = ( ticketID, emailbody, mailproc.getCurrentTime(), username, changelog, 0)
+			data = ( ticketID, emailbody, mailproc.getCurrentTime(), userid, changelog, 0)
 			cursor.execute (sql, data)
 			commentid = cursor.lastrowid
 			mailproc.log("Inserted email ticket comment (" + str(commentid) +  ") into database")
